@@ -15,13 +15,13 @@ class NotificationManager : public QObject
     Q_OBJECT
 public:
     explicit NotificationManager(QObject *parent = nullptr);
-    ~NotificationManager();
+    ~NotificationManager() = default;
 
     /**
      * @argument valid: to check whether the returned url after sharing is valid or not
      * @argument url: the valid url returned after sharing the image
      */
-    Q_INVOKABLE void showNotification(bool valid, QVariant url = QVariant());
+    Q_INVOKABLE void showNotification(bool valid, const QVariant &url = QVariant());
 
 private:
     KNotification *m_sharingSuccess;
